@@ -21,7 +21,7 @@
  * along with "ADI USB ADSL Driver for Linux"; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: Me.c,v 1.2 2004/06/04 18:56:19 sleeper Exp $
+ * $Id: Me.c,v 1.3 2004/09/12 20:00:46 sleeper Exp $
  */
 
 /*************************************************************************************/
@@ -263,9 +263,9 @@ void WatchdogTimer(unsigned long ptr)
 int SetTimerInterval(eu_instance_t* ins, int reqDelay)
 {
     AdiMSM   *pAdiSm = &(ins->AdiModemSm);
-    int curtime = jiffies;
-    int delay   = MSEC_TO_JIFFIES(reqDelay);
-    int exptime;
+    unsigned long curtime = jiffies;
+    long delay   = MSEC_TO_JIFFIES(reqDelay);
+    unsigned long exptime;
 
     eu_enters (DBG_MSG);
     eu_dbg (DBG_MSG,"Requested delay = %d\n",reqDelay);
@@ -281,7 +281,7 @@ int SetTimerInterval(eu_instance_t* ins, int reqDelay)
     /*calculate the minimal delay requested*/
     if ( curtime < pAdiSm->SwapPageRequiredTime )
     {
-        int newDelay;
+        long newDelay;
         newDelay = pAdiSm->SwapPageRequiredTime - curtime;
         if ( delay < newDelay )
             delay = newDelay;
@@ -302,6 +302,9 @@ int SetTimerInterval(eu_instance_t* ins, int reqDelay)
 
 /********************************************************************
 $Log: Me.c,v $
+Revision 1.3  2004/09/12 20:00:46  sleeper
+Fix jiffies computation plus error/dbg string for AMD64 portation
+
 Revision 1.2  2004/06/04 18:56:19  sleeper
 Cosmetics
 
