@@ -1,5 +1,5 @@
 
-/* $Id: Oam.c,v 1.3 2004/06/04 18:56:19 sleeper Exp $ */
+/* $Id: Oam.c,v 1.4 2004/09/12 20:00:46 sleeper Exp $ */
 
 //---------------------------------------------------------------------------
 //
@@ -539,7 +539,7 @@ static void USBSendAmoeba(eu_instance_t *ins, UInt8 *pCell, Boolean MoreThanOneC
     UInt8 MyCell[ATM_CELL_SIZE*2];
 
     eu_enters (DBG_OAM);
-    eu_dbg (DBG_OAM,"******* FFD >>>> ins = 0x%x\n", (unsigned int)ins);
+    eu_dbg (DBG_OAM,"******* FFD >>>> ins = %#lx\n", (unsigned long)ins);
 
    if ( MoreThanOneCell == TRUE )
 	uiTotalBytes = ATM_CELL_SIZE*2;
@@ -549,9 +549,9 @@ static void USBSendAmoeba(eu_instance_t *ins, UInt8 *pCell, Boolean MoreThanOneC
     memcpy(MyCell,pCell,uiTotalBytes);	
 
     for (cntr=0;cntr<uiTotalBytes;cntr++)
-        eu_dbg (DBG_OAM," 0x%#x ", MyCell[cntr]);
+        eu_dbg (DBG_OAM," %#x ", MyCell[cntr]);
 
-        eu_dbg (DBG_OAM,"\n *** OAM **** Writing 0x%#x bytes to USB\n", uiTotalBytes);
+        eu_dbg (DBG_OAM,"\n *** OAM **** Writing %#x bytes to USB\n", uiTotalBytes);
 
 
     FILL_BULK_URB ( ins->urb_oam_write, ins->usbdev,
