@@ -24,7 +24,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *
- * $Id: Pipes.c,v 1.5 2004/06/04 18:56:19 sleeper Exp $
+ * $Id: Pipes.c,v 1.8 2005/01/17 20:54:42 sleeper Exp $
  */
 
 #include "Adiutil.h"
@@ -345,7 +345,7 @@ static USB_COMPLETION_PROTO (eu_bulk_read_completion,urb,regs)
 
     if (
         ( urb->status == -ENOENT ) ||
-        (urb->status == -ECONNRESET ) 
+        (urb->status == -ECONNRESET ) ||
         ( urb->status == -ESHUTDOWN )
        )
     {
@@ -533,9 +533,10 @@ static USB_COMPLETION_PROTO (eu_iso_read_completion,urb,regs)
     }
 
     if (
-        ( urb->status == -ENOENT ) ||
+        ( urb->status == -ENOENT )     ||
         ( urb->status == -ECONNRESET ) ||
-        ( urb->status == -ENOENT )
+        ( urb->status == -ENOENT )     ||
+        ( urb->status == -ENODEV )
        )
     {
 
@@ -654,8 +655,7 @@ void eu_stop_read_pipe ( eu_instance_t *ins )
         if ( ins->read_urb[i]) 
         {
             eu_dbg (DBG_READ,"About to unlink read urb %u\n",i);
-            ins->read_urb[i]->transfer_flags &= ~URB_ASYNC_UNLINK;
-            usb_unlink_urb( ins->read_urb[i] );
+            USB_KILL_URB( ins->read_urb[i] );
             
             eu_dbg (DBG_READ,"Read urb %u unlinked.\n",i);
         }
