@@ -21,7 +21,7 @@
  * along with "ADI USB ADSL Driver for Linux"; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: Sm.c,v 1.5 2004/06/30 20:32:02 sleeper Exp $
+ * $Id: Sm.c,v 1.6 2004/09/27 21:59:07 mcoolive Exp $
  */
 
 #include "Adiutil.h"
@@ -715,7 +715,7 @@ void ModemSM(UInt16 uEventCode, eu_instance_t *ins, void *pData)
                                     {
                                         eu_dbg (DBG_SM,"OPSTAT step1 CRC thresh RESET\n");
                                         
-                                        eu_err("CRC count treshold reached. Rebooting\n");
+                                        eu_err("CRC count threshold reached. Rebooting\n");
                                         ResetModemSM(pAdiSM);
                                     }
                                 }
