@@ -28,7 +28,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *
- * $Id: eu_main.c,v 1.15 2004/08/26 20:06:34 sleeper Exp $
+ * $Id: eu_main.c,v 1.25 2005/01/17 20:54:42 sleeper Exp $
  */
 
 #include "Adiutil.h"
@@ -61,7 +61,8 @@
     case HEINEKEN_A_PID_PREFIRM:                \
     case HEINEKEN_B_PID_PREFIRM:                \
     case EAGLE_IIC_PID_PREFIRM:                 \
-    case EAGLE_II_PID_PREFIRM
+    case EAGLE_II_PID_PREFIRM:                  \
+    case EAGLE_III_PID_PREFIRM
 
 
 #define CASE_POSTFIRM	EAGLE_I_PID_PSTFIRM:    \
@@ -70,18 +71,21 @@
     case HEINEKEN_A_PID_PSTFIRM:                \
     case HEINEKEN_B_PID_PSTFIRM:                \
     case EAGLE_II_PID_PSTFIRM:                  \
-    case EAGLE_IIC_PID_PSTFIRM
+    case EAGLE_IIC_PID_PSTFIRM:                 \
+    case EAGLE_III_PID_PSTFIRM
 
 #define ISPREFIRM(c) ( EAGLE_I_PID_PREFIRM == (c)                                     ||        \
                        MILLER_A_PID_PREFIRM   == (c) || MILLER_B_PID_PREFIRM == (c)   ||        \
                        HEINEKEN_A_PID_PREFIRM == (c) || HEINEKEN_B_PID_PREFIRM == (c) ||        \
-                       EAGLE_II_PID_PREFIRM   == (c) || EAGLE_IIC_PID_PREFIRM == (c)            \
+                       EAGLE_II_PID_PREFIRM   == (c) || EAGLE_IIC_PID_PREFIRM == (c)  ||        \
+                       EAGLE_III_PID_PREFIRM  == (c)                                            \
                      )
 
 #define ISPOSTFIRM(c) ( EAGLE_I_PID_PSTFIRM == (c)                                     ||       \
                         MILLER_A_PID_PSTFIRM   == (c) || MILLER_B_PID_PSTFIRM == (c)   ||       \
                         HEINEKEN_A_PID_PSTFIRM == (c) || HEINEKEN_B_PID_PSTFIRM == (c) ||       \
-                        EAGLE_II_PID_PSTFIRM   == (c) || EAGLE_IIC_PID_PSTFIRM == (c)           \
+                        EAGLE_II_PID_PSTFIRM   == (c) || EAGLE_IIC_PID_PSTFIRM == (c)  ||       \
+                        EAGLE_III_PID_PSTFIRM  == (c)                                           \
                       )
 
 
@@ -150,6 +154,8 @@ static const struct usb_device_id eu_ids[] =
     {  USB_DEVICE (EAGLE_VID, EAGLE_II_PID_PSTFIRM) },
     {  USB_DEVICE (EAGLE_VID, EAGLE_IIC_PID_PREFIRM) },
     {  USB_DEVICE (EAGLE_VID, EAGLE_IIC_PID_PSTFIRM) },
+    {  USB_DEVICE (EAGLE_VID, EAGLE_III_PID_PREFIRM) },
+    {  USB_DEVICE (EAGLE_VID, EAGLE_III_PID_PSTFIRM) },
     {  USB_DEVICE (USR_VID, MILLER_A_PID_PREFIRM) },
     {  USB_DEVICE (USR_VID, MILLER_A_PID_PSTFIRM) },
     {  USB_DEVICE (USR_VID, MILLER_B_PID_PREFIRM) },
@@ -232,6 +238,11 @@ static char *if_name = NULL;
  */
 unsigned int module_dbg_mask = 0x0;
 
+/*
+ * Chipset version
+ */
+static unsigned int chipset_version = 0;
+
 
 /* -------------------------------- Module Stuff -------------------------------- */
 
@@ -372,7 +383,8 @@ static int eu_probe (
             ins = eu_init_postfirm ( usb, intf );
 #else
             ins = eu_init_postfirm ( usb );
-#endif            
+#endif
+            
             break;
     }
     
@@ -435,7 +447,7 @@ static eu_instance_t *eu_init_prefirm ( struct usb_device *usb )
             
     eu_report ("Uploading firmware..\n");
     
-    ret = eu_load_firmware ( ins, pid );
+    ret = eu_load_firmware ( ins, pid, &chipset_version );
     if ( ret < 0 ) 
     {
         eu_err ("Can't upload firmware to modem...\n");
@@ -558,9 +570,11 @@ static eu_instance_t * eu_init_postfirm ( struct usb_device *usb )
     /*
      * Get a lookaside cache
      */
-    ins->rb_cache = kmem_cache_create ( "eagle-usb",
-                                        sizeof(eu_rb_t),
-                                        0,0, NULL,NULL);
+    snprintf ( path,32,"eagle-usb-%03d-%03d",
+               ins->usbdev->bus->busnum,
+               ins->usbdev->devnum);
+    
+    ins->rb_cache = kmem_cache_create ( path, sizeof(eu_rb_t),0,0, NULL,NULL);
 
     if ( !ins->rb_cache ) 
     {                
@@ -695,6 +709,9 @@ static eu_instance_t * eu_init_postfirm ( struct usb_device *usb )
         eu_report ("Failed to claim interface 2 (%d)\n",-tmp);
         goto release_intf_1;
     }
+
+    ins->users = 3;
+    
     
 #ifndef USEBULK
 
@@ -776,6 +793,7 @@ static eu_instance_t * eu_init_postfirm ( struct usb_device *usb )
     /*
      * We're successfull !!!!
      */
+    eu_dbg (DBG_INIT,"nb of users: %u\n",ins->users);
     goto byebye;
 
   release_intf_1:
@@ -822,6 +840,7 @@ static eu_instance_t * eu_init_postfirm ( struct usb_device *usb )
     
   free_instance:
     FREE_KBUFFER (ins);
+    ins = NULL;
     
   byebye:
     eu_leaves ( DBG_INIT);
@@ -863,6 +882,11 @@ static void eu_disconnect ( struct usb_interface *intf )
         goto dis_done;
     }
 
+#ifdef LINUX_2_6    
+    eu_dbg (DBG_INIT,"intf=0x%p intfdate=0x%p ins = 0x%p\n",
+            intf,usb_get_intfdata (intf),ins);
+#endif
+    
     /*
      * Do nothing if you also have no usbdev associated
      */
@@ -872,8 +896,11 @@ static void eu_disconnect ( struct usb_interface *intf )
         goto dis_done;
     }
     
+    eu_dbg (DBG_INIT,"ins->usbdev = 0x%p\n",ins->usbdev);
     
     EU_SET_FLAG (ins, EU_UNPLUG);
+
+    eu_dbg (DBG_INIT,"Let check PID\n");
     
     switch (pid)
     {
@@ -888,16 +915,21 @@ static void eu_disconnect ( struct usb_interface *intf )
         
     case CASE_POSTFIRM:
 
-        ins->usbdev = NULL;
+/*         ins->usbdev = NULL; */
 
 #ifdef LINUX_2_6
     usb_set_intfdata (intf, NULL);
 #endif
         eu_disconnect_postfirm (ins,usb);
+        
+        ins = NULL;
 	break;
     }
-
-
+    
+#ifdef LINUX_2_6
+    eu_dbg (DBG_INIT,"intf=0x%p intfdata=0x%p ins=0x%p\n",intf,usb_get_intfdata (intf),ins);
+#endif
+    
 dis_done:
     eu_leaves (DBG_INIT);
 }
@@ -914,7 +946,32 @@ static void eu_disconnect_postfirm ( eu_instance_t *ins , struct usb_device *usb
     int i;
     char path[32];
 
+    /*
+     * Unlink pending interrupt URBs
+     */
+    if ( EU_TEST_FLAG ( ins, EU_HAS_INT ) )
+    {
+        eu_dbg (DBG_INIT,"Stop interrupt URB\n");
+        USB_KILL_URB(ins->urb_int);
+        usb_free_urb (ins->urb_int);
+        EU_CLEAR_FLAG (ins, EU_HAS_INT);
+    }
 
+
+    /*
+     * Decrement the number of user, and destroy this instance only if this
+     * number reaches 0
+     */
+    ins->users --;
+    
+    eu_dbg (DBG_INIT,"nb of users: %u\n",ins->users);
+
+    if ( ins->users > 0 ) 
+    {
+        eu_dbg (DBG_INIT,"Still %u user(s).. Do nothing\n",ins->users);
+        return;
+    }
+    
     /*
      * If timers are currently running, delete them:
      */
@@ -938,15 +995,6 @@ static void eu_disconnect_postfirm ( eu_instance_t *ins , struct usb_device *usb
      */
     EU_FLUSH (eu_>boot_sm);
     
-    /*
-     * Unlink pending interrupt URBs
-     */
-    if ( EU_TEST_FLAG ( ins, EU_HAS_INT ) )
-    {
-        ins->urb_int->transfer_flags &= ~URB_ASYNC_UNLINK;
-        usb_unlink_urb(ins->urb_int);
-        usb_free_urb (ins->urb_int);
-    }
     
     /*
      * Free the DSP code:
@@ -974,7 +1022,7 @@ static void eu_disconnect_postfirm ( eu_instance_t *ins , struct usb_device *usb
          * This will call the eu_close method:
          */
         unregister_netdev ( ins->eth );
-        kfree ( ins->eth );
+        EU_FREE_NETDEV ( ins->eth );
         ins->eth = NULL;
     }
     
@@ -998,8 +1046,7 @@ static void eu_disconnect_postfirm ( eu_instance_t *ins , struct usb_device *usb
 
         if ( ins->read_urb[i] ) 
         {
-            ins->read_urb[i]->transfer_flags &= ~URB_ASYNC_UNLINK;
-            usb_unlink_urb ( ins->read_urb[i] );
+            USB_KILL_URB ( ins->read_urb[i] );
             usb_free_urb ( ins->read_urb[i] );
             ins->read_urb[i] = NULL;
         }
@@ -1020,15 +1067,13 @@ static void eu_disconnect_postfirm ( eu_instance_t *ins , struct usb_device *usb
     /*
      * Free write urb: it has been unlinked in eu_eth_close
      */
-    ins->urb_write->transfer_flags &= ~URB_ASYNC_UNLINK;
-    usb_unlink_urb ( ins->urb_write );
+    USB_KILL_URB ( ins->urb_write );
     usb_free_urb ( ins->urb_write );
 
     /*
      * Free urb_oam_write
      */
-    ins->urb_oam_write->transfer_flags &= ~URB_ASYNC_UNLINK;
-    usb_unlink_urb(ins->urb_oam_write);
+    USB_KILL_URB(ins->urb_oam_write);
     usb_free_urb ( ins->urb_oam_write );
     
 
@@ -1052,13 +1097,13 @@ static void eu_disconnect_postfirm ( eu_instance_t *ins , struct usb_device *usb
      */
     usb_driver_release_interface ( &eu_driver, GET_INTF_PTR (usb,2) );
 #endif
-    
-#if 0            
+
+#if USE_CMVS
     if ( ins->pDriverCMVs )
     {
         FREE_VBUFFER ( ins->pDriverCMVs );
     }
-#endif
+#endif /* USE_CMVS */
             
     list_del ( &ins->list );
             
@@ -1098,9 +1143,11 @@ static USB_COMPLETION_PROTO (eu_irq,urb,regs)
     }
 
     if  (
-         ( urb->status ==  -ENOENT ) ||
+         ( urb->status == -ENOENT )     ||
          ( urb->status == -ECONNRESET ) ||
-         ( urb->status == -ESHUTDOWN )
+         ( urb->status == -ESHUTDOWN )  ||
+         ( urb->status == -EILSEQ )     ||
+         ( urb->status == -ENODEV )
         )
     {
         /*
@@ -1286,15 +1333,9 @@ static int eu_user ( struct usb_interface *intf, unsigned int code, void *buf )
         case CASE_POSTFIRM:
             switch (code)
             {                    
-#if 0            
+#if USE_CMVS           
                 case EU_IO_CMVS:
                     retval = -ERESTARTSYS;
-                    if ( !spin_trylock ( &ins->net_lock ) ) 
-                    {
-                        eu_err ("EU_IO_CMVS : Can't lock\n");
-                        break;
-                    }
-
                     if ( ins->flags & EU_OPEN ) 
                     {
                         retval = -EBUSY;
@@ -1350,10 +1391,9 @@ static int eu_user ( struct usb_interface *intf, unsigned int code, void *buf )
                     retval = 0;
                     
               end_set_cmvs:
-                    spin_unlock ( &ins->net_lock);
                     
                     break;
-#endif
+#endif /* USE_CMVS */
                     
                 case EU_IO_OPTIONS:		/* Set driver options */
                     /*
@@ -1361,15 +1401,15 @@ static int eu_user ( struct usb_interface *intf, unsigned int code, void *buf )
                      */
             
 
-#if 0
+#if USE_CMVS
                     if ( ins->pDriverCMVs == NULL ) 
                     {
                         /* User as not yet sent EU_IO_CMVS */
                         eu_err ("EU_IO_OPTIONS: CMVs not yet sent.\n");
                         retval = -ERESTARTSYS;
-                        goto end_set_options;
+                        break;
                     }
-#endif                    
+#endif /* USE_CMVS */
             
                     if (!( EU_TEST_FLAG (ins, EU_OPEN ) ) )
                     {
@@ -1560,8 +1600,14 @@ static int eu_user ( struct usb_interface *intf, unsigned int code, void *buf )
                              * Install the interrupt handler to send IDMA pages to the modem
                              * and handle further incoming data
                              */
-                            usb_fill_int_urb ( ins->urb_int, dev, ins->pipe_int_in, ins->intr_data,
-                                               sizeof(eu_cdc_t), eu_irq, ins, interval );
+                            usb_fill_int_urb ( ins->urb_int,
+                                               dev,
+                                               ins->pipe_int_in,
+                                               ins->intr_data,
+                                               sizeof(eu_cdc_t),
+                                               eu_irq,
+                                               ins,
+                                               interval );
 
                             EU_SET_FLAG (ins, EU_HAS_INT);
                             
@@ -1695,9 +1741,19 @@ static int eu_read_proc ( char *page,
      */
     p += sprintf(p, "eagle-usb status display\n");
     p += sprintf(p, "-------------------------------------------------------------\n");
-    p += sprintf(p, "Driver version %s\n",EAGLEUSBVERSION);
-    p += sprintf(p, "USB Bus : %03d\t USB Device : %03d\t Dbg mask: 0x%x\n",
-                 ins->usbdev->bus->busnum, ins->usbdev->devnum, module_dbg_mask);
+    p += sprintf(p, "Driver version %s     Chipset: Eagle%1.1d\n",
+                 EAGLEUSBVERSION, chipset_version);
+    
+    if (ins->usbdev != NULL)
+    {
+        p += sprintf (p,"Vendor ID : 0x%x     Product ID : 0x%x   Rev: 0x%x\n",
+                      ins->usbdev->descriptor.idVendor,
+                      ins->usbdev->descriptor.idProduct,
+                      ins->usbdev->descriptor.bcdDevice);
+        p += sprintf(p, "USB Bus : %03d\t USB Device : %03d\t Dbg mask: 0x%x\n",
+                     ins->usbdev->bus->busnum, ins->usbdev->devnum, module_dbg_mask);
+    }
+    
     if (ins->eth->name)
     {
         p += sprintf(p, "Ethernet Interface : %s\n",ins->eth->name);
@@ -1710,20 +1766,19 @@ static int eu_read_proc ( char *page,
                  ins->mac[0],ins->mac[1],ins->mac[2],ins->mac[3],ins->mac[4],
                  ins->mac[5]);
     
-    p += sprintf(p, "Tx Rate  %10.10d  Rx Rate  %10.10d  Crc      %10.10d\n",
+    p += sprintf(p, "Tx Rate  %10d  Rx Rate  %10d\n",
                  ins->AdiModemSm.UpRate / 1024, 
-                 ins->AdiModemSm.DownRate / 1024, 
-                 ins->Statistics[STAT_CELLS_LOST_CRC]);
-    p += sprintf(p, "FEC      %10.10d  Margin   %10.10d  Atten    %10.10d dB\n",
+                 ins->AdiModemSm.DownRate / 1024);
+    p += sprintf(p, "FEC      %10d  Margin   %10d  Atten    %10d dB\n",
                  ins->AdiModemSm.stats_Uncorr_Blks,
                  ins->AdiModemSm.stats_Cur_SNR & 0xFF,
                  (ins->AdiModemSm.stats_Cur_Atten & 0xFF)/2);
-    p += sprintf(p, "VID-CPE  %10.10d  VID-CO   %10.10d  HEC      %10.10d\n",
+    p += sprintf(p, "VID-CPE  %10d  VID-CO   %10d  HEC      %10d\n",
                  ins->AdiModemSm.INFO14,
                  ins->AdiModemSm.INFO08,
                  ins->AdiModemSm.DIAG03);
 
-    p += sprintf(p, "VPI      %10.10d  VCI      %10.10d  Delin         ", 
+    p += sprintf(p, "VPI      %10d  VCI      %10d  Delin         ", 
                  ins->Vc.vpi, ins->Vc.vci);
 
     /*Delineation is the only one where we print a string instead of a number*/
@@ -1734,18 +1789,18 @@ static int eu_read_proc ( char *page,
 	    p += sprintf(p, " LOSS\n");
 	else
 	    p += sprintf(p, " GOOD\n");
-    p += sprintf(p, "Cells Rx %10.10d  Cells Tx %10.10d\n",
-                 ins->Statistics[STAT_CELLS_RX],
-                 ins->Statistics[STAT_CELLS_TX]);
-    p += sprintf(p, "Pkts Rx  %10.10d  Pkts Tx  %10.10d\n",
-                 ins->Statistics[STAT_PAKTS_RX],
-                 ins->Statistics[STAT_PAKTS_TX]);
-    p += sprintf(p, "OAM      %10.10d  Bad VPI  %10.10d  Bad CRC  %10.10d\n",
+    p += sprintf(p, "Cells Tx %10d  Cells Rx %10d\n",
+                 ins->Statistics[STAT_CELLS_TX],
+                 ins->Statistics[STAT_CELLS_RX]);
+    p += sprintf(p, "Pkts Tx  %10d  Pkts Rx  %10d\n",
+                 ins->Statistics[STAT_PAKTS_TX],
+                 ins->Statistics[STAT_PAKTS_RX]);
+    p += sprintf(p, "OAM      %10d  Bad VPI  %10d  Bad CRC  %10d\n",
                   ins->Statistics[STAT_CELLS_OAM_RCVD],
                   ins->Statistics[STAT_CELLS_LOST_VPIVCI],
                   ins->Statistics[STAT_CELLS_LOST_CRC]
                   );
-    p += sprintf(p, "Oversiz. %10.10d\n\n",
+    p += sprintf(p, "Oversiz. %10d\n\n",
                 ins->Statistics[STAT_CELLS_LOST_OTHER] );
     
     switch (ins->AdiModemSm.CurrentAdiState)
