@@ -20,7 +20,7 @@
  * along with "ADI USB ADSL Driver for Linux"; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: eu_types.h,v 1.4 2004/07/13 19:01:48 sleeper Exp $
+ * $Id: eu_types.h,v 1.8 2004/11/07 09:06:55 sleeper Exp $
  */
 #ifndef __EU_TYPES_H__
 #define __EU_TYPES_H__
@@ -51,7 +51,7 @@ struct eu_ioctl_info
 #define EU_IO_SYNC    _IO('U',   104)
 #define EU_IO_GETDBG  _IOWR('U', 105, struct eu_ioctl_info)
 #define EU_IO_SETDBG  _IOWR('U', 106, struct eu_ioctl_info)
-#if 0
+#if USE_CMVS
 #define EU_IO_CMVS    _IOW('U',  107, struct eu_ioctl_info)
 #endif
 
@@ -162,7 +162,7 @@ typedef struct
     uint16_t wIndex;
     uint16_t wLength;
     uint8_t data[20];
-} eu_cdc_t __attribute__ ((packed));
+} __attribute__ ((packed)) eu_cdc_t;
 
 
 /**
@@ -671,9 +671,14 @@ typedef struct
 
 typedef struct eu_instance_s
 {
-
     /*
-     * To protet acesses to this structure.
+     * To count the number of interfaces linked to this structure ...
+     */
+    uint32_t users;
+
+    
+    /*
+     * To protect accesses to this structure.
      */
     spinlock_t lock;
     
