@@ -21,7 +21,7 @@
  * along with "ADI USB ADSL Driver for Linux"; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: eu_utils.c,v 1.4 2004/06/04 18:56:19 sleeper Exp $
+ * $Id: eu_utils.c,v 1.11 2005/01/17 20:54:42 sleeper Exp $
  */
 
 #include "Adiutil.h"
@@ -69,7 +69,7 @@ static uint8_t htoi ( uint8_t h );
  * eu_load_firmware - Load firmware into pre-firmware devices.
  *
  */
-int eu_load_firmware ( eu_instance_t *ins, uint32_t pid ) 
+int eu_load_firmware ( eu_instance_t *ins, uint32_t pid, unsigned int *ver ) 
 {
     int ret= 0;
     uint8_t value;
@@ -94,12 +94,29 @@ int eu_load_firmware ( eu_instance_t *ins, uint32_t pid )
     if ( IS_EAGLE_I (pid) ) 
     {
         pfirm = &eu_eagle_I_firmware[0];
+        if (ver != NULL) 
+        {
+            *ver = 1;
+        }
+        
     }
-    else
+    else  if ( !IS_EAGLE_III (pid) )
     {
         pfirm = &eu_eagle_II_firmware[0];
+        if (ver != NULL) 
+        {
+            *ver = 2;
+        }
     }
-
+    else 
+    {
+  		pfirm = &eu_eagle_III_firmware[0];      
+        if (ver != NULL) 
+        {
+            *ver = 3;
+        }
+    }
+    
     i = 0;
 
     while ( pfirm->type == 0 ) 
@@ -160,7 +177,7 @@ int eu_cmd_to_modem (
     
     if ( !xfer_buff )
     {
-        eu_err ("eu_cmd_to_modem: Cannot allocate 0x%x bytes\n",count+sizeof(devrequest));        
+        eu_err ("eu_cmd_to_modem: Cannot allocate %#lx bytes\n",(unsigned long)count+sizeof(devrequest));        
 	ret = -ENOMEM;
 	goto byebye;
     }
@@ -357,15 +374,22 @@ void ctrl_urb_retry_send ( unsigned long ptr )
     ret = USB_SUBMIT_URB ( ins->ctrl_urb_failed , GFP_ATOMIC );
     if ( ret != 0 ) 
     {
-        eu_err ("ADI: Failed to send faulty ctrl urb (%p) with err=%d\n",
-                        ins->ctrl_urb_failed ,ret);
-        eu_err ("ADI: retry in 100ms\n");
+        if ( ret == -ENODEV ) 
+        {
+            eu_err ("ctrl_urb_retry_send: -ENODEV received ... I give up.\n");
+        }
+        else 
+        {
+            eu_err ("ctrl_urb_retry_send: Failed to send faulty ctrl urb (%p) with err=%d\n",
+                    ins->ctrl_urb_failed ,ret);
+            eu_err ("ctrl_urb_retry_send: retry in 100ms\n");
 
-        /*
-         * Schedule retry send in 100 ms
-         */
-        ins->ctrl_urb_retry.expires = jiffies + MSEC_TO_JIFFIES (100);
-        add_timer ( &ins->ctrl_urb_retry );
+            /*
+             * Schedule retry send in 100 ms
+             */
+            ins->ctrl_urb_retry.expires = jiffies + MSEC_TO_JIFFIES (100);
+            add_timer ( &ins->ctrl_urb_retry );
+        }
     }
     else
     {
@@ -411,8 +435,7 @@ void unlink_ipg_ctrl_urb ( eu_instance_t *ins )
          */
         qhead = list_entry ( ins->ctrl_urb_ipg_q.next, queued_urb_t, list);
         
-        qhead->urb->transfer_flags &= ~URB_ASYNC_UNLINK;
-        usb_unlink_urb(qhead->urb);
+        USB_KILL_URB(qhead->urb);
     }
     
     spin_unlock_irqrestore (&ins->ctrl_q_lock, flags);
@@ -515,8 +538,15 @@ void queue_ctrl_urb(eu_instance_t *ins, struct urb *urb)
         {
             eu_err ("Failed to send ctrl urb (%p) with err=%d\n",
                     urb,ret);
-            eu_err ("retry in 100ms\n");
-
+            if ( ret == -ENODEV ) 
+            {
+                eu_err ("This is a \"no device\" error ... I give up.\n");
+                goto byebye;
+            }
+            else
+            {            
+                eu_err ("Let's retry in 100ms\n");
+            }
             /*
              * Schedule retry send in 200 ms
              */
@@ -763,7 +793,16 @@ static void rm_queued_urb(struct urb *urb)
         {
             eu_err ("Failed to send pending ctrl urb (%p) with err=%d\n",
                     qhead->urb,ret);
-            eu_err ("Retrying in 100 ms\n");
+                        if ( ret == -ENODEV ) 
+            {
+                eu_err ("This is a \"no device\" error ... I give up.\n");
+                goto free_urb_and_quit;
+            }
+            else
+            {            
+                eu_err ("Let's retry in 100ms\n");
+            }
+
             
             /*
              * Schedule retry send in 200 ms
