@@ -72,10 +72,10 @@
 
 #define OPTS_FILE    "eagle-usb.conf"
 
-#if 0
-#define DEFAULT_CMV_ISDN_FILE   "/etc/analog/CMVei.txt"
-#define DEFAULT_CMV_POTS_FILE   "/etc/analog/CMVep.txt"
-#endif
+#if USE_CMVS
+#define DEFAULT_CMV_ISDN_FILE   CONF_DIR "/CMVei.txt"
+#define DEFAULT_CMV_POTS_FILE   CONF_DIR "/CMVep.txt"
+#endif /* USE_CMVS */
 
 #define MAX_PATH_LENGTH     255
 
@@ -106,9 +106,9 @@
 #define DO_WIZARD     (1<<5)
 #define DO_GETDBG     (1<<6)
 #define DO_SETDBG     (1<<7)
-#if 0
+#if USE_CMVS
 #define DO_CMVS       (1<<8)
-#endif
+#endif /* USE_CMVS */
 
 #define SKIP_BLANKS(p)                                          \
     while ((*(p) !='\0') &&                                     \
@@ -158,6 +158,10 @@
 #define TYPE_MEMACCESS          0x1000
 #define WRITE_TO_MODEM (RECEIVER_MODEM + SENDER_HOST + SUBTYPE_MEM_REQWRITE + TYPE_MEMACCESS)
 
+#if USE_CMVS
+#define MAX_CMVS_COUNT   100
+#endif
+
 /* ----------------------------------- Types ------------------------------------ */
 
 /**
@@ -260,9 +264,9 @@ static struct option long_options[] = {
     {"help", no_argument, 0, 'h'},
     {"version", no_argument, 0, 'v'},
     {"options", optional_argument, 0, 'o'},
-#if 0    
+#if USE_CMVS   
     {"cmvs", optional_argument, 0, 'c'},
-#endif
+#endif /* USE_CMVS */
     {"dsp", optional_argument, 0, 'd'},
     {"sync", optional_argument, 0, 's'},
     {"print", no_argument, 0, 'p'},
@@ -288,8 +292,8 @@ typedef struct
 static dbg_opt_t debug_flags[15] = {
     { "SAR","        Segmentation and Reassembly subsystem",DBG_SAR},
     { "UNI",        "        User-Network Inferface subsystem",DBG_UNI},
-    { "MPOA", "        Multi-Porotocol Over ATM subsystem",DBG_MPOA},
-    { "INIT", "        Initilization subsystem",DBG_INIT},
+    { "MPOA", "        Multi-Protocol Over ATM subsystem",DBG_MPOA},
+    { "INIT", "        Initialization subsystem",DBG_INIT},
     { "ENET","        Ethernet subsystem",DBG_ENET},
     { "BOOT","        Boot subsystem",DBG_BOOT},
     { "UTILS","        Utils subsystem",DBG_UTILS},
@@ -317,6 +321,7 @@ static product_t supported_products[] = {
     {  EAGLE_VID, EAGLE_I_PID_PREFIRM,      PRE_FIRMWARE },
     {  EAGLE_VID, EAGLE_II_PID_PREFIRM,     PRE_FIRMWARE },
     {  EAGLE_VID, EAGLE_IIC_PID_PREFIRM,    PRE_FIRMWARE },
+    {  EAGLE_VID, EAGLE_III_PID_PREFIRM,    PRE_FIRMWARE }, /* Eagle III */
     {  USR_VID,   MILLER_A_PID_PREFIRM,     PRE_FIRMWARE },
     {  USR_VID,   MILLER_B_PID_PREFIRM,     PRE_FIRMWARE },
     {  USR_VID,   HEINEKEN_A_PID_PREFIRM,   PRE_FIRMWARE },
@@ -327,6 +332,7 @@ static product_t supported_products[] = {
     {  EAGLE_VID, EAGLE_I_PID_PSTFIRM,      POST_FIRMWARE },
     {  EAGLE_VID, EAGLE_II_PID_PSTFIRM,     POST_FIRMWARE },
     {  EAGLE_VID, EAGLE_IIC_PID_PSTFIRM,    POST_FIRMWARE },
+    {  EAGLE_VID, EAGLE_III_PID_PSTFIRM,    POST_FIRMWARE }, /* Eagle III */
     {  USR_VID,   MILLER_A_PID_PSTFIRM,     POST_FIRMWARE },
     {  USR_VID,   MILLER_B_PID_PSTFIRM,     POST_FIRMWARE },
     {  USR_VID,   HEINEKEN_A_PID_PSTFIRM,   POST_FIRMWARE },
@@ -383,7 +389,6 @@ static void check_device ( usb_dev_desc_t *ud , const char *dev_name, int bus);
 static int get_devices ( void );
 static int send_dsp ( const char *file );
 static int send_options ( const char *file );
-static uint8_t hex_to_byte(char c);
 static void synchro_timed_out ( int sig );
 static int wizard (const char *cmvs, const char *opts, const char *dsp,
                    unsigned int seconds );
@@ -391,14 +396,14 @@ static int manage_dbg_mask ( unsigned int options, unsigned int dbg_mask );
 static void list_debug_flags (void );
 static int parse_dbg_flags ( char *flagstr, unsigned int *flags );
 static void format_dbg_string (char *buf,unsigned int mask );
-#if 0
+#if USE_CMVS
 static int send_cmvs ( const char *file );
 static int read_cmv_from_file (
                                const char *filename,
-                               cmv_msg_t drv_cmvs[100],
+                               cmv_msg_t *drv_cmvs,
                                unsigned int *nb_cmvs
                               );
-#endif
+#endif /* USE_CMVS */
 
 
 int main (int argc, char *argv[] ) 
@@ -476,7 +481,7 @@ int main (int argc, char *argv[] )
                 options_set |= DO_OPTS;
                 break;
 
-#if 0                
+#if USE_CMVS               
             case 'c':
                 if ( optarg ) 
                 {
@@ -485,7 +490,7 @@ int main (int argc, char *argv[] )
                 }
                 options_set |= DO_CMVS;
                 break;
-#endif
+#endif /* USE_CMVS */
                 
             case 's':
 
@@ -531,7 +536,7 @@ int main (int argc, char *argv[] )
                  */
                 if ( isdigit (optarg[0]) ) 
                 {
-                    dbg_mask = strtol(optarg, (char **)NULL, 16);
+                    dbg_mask = strtoul(optarg, (char **)NULL, 16);
                 }
                 else
                 {
@@ -588,9 +593,9 @@ int main (int argc, char *argv[] )
         if ( options_set & DO_DSP ) 
         {
             options_set |= DO_OPTS;
-#if 0            
+#if USE_CMVS           
             options_set |= DO_CMVS;
-#endif            
+#endif /* USE_CMVS */
         }
         
         
@@ -611,13 +616,13 @@ int main (int argc, char *argv[] )
         
         if ( options_set & DO_DSP ) 
         {
-#if 0            
+#if USE_CMVS           
             retcode = send_cmvs ( cmvs_file );
             if ( retcode == EXIT_FAILURE ) 
             {
                 goto byebye;
             }
-#endif            
+#endif /* USE_CMVS */
             retcode = send_options ( options_file );
             if ( retcode == EXIT_FAILURE ) 
             {
@@ -812,7 +817,7 @@ static int send_options ( const char *file )
     
 }
 
-#if 0
+#if USE_CMVS
 static int send_cmvs ( const char *file ) 
 {
     int                   fd      = -1;
@@ -820,7 +825,7 @@ static int send_cmvs ( const char *file )
     int                   res;
     struct usbdevfs_ioctl ioc;
     struct eu_ioctl_info ioc_info;
-    cmv_msg_t             drv_cmvs[100];
+    cmv_msg_t             drv_cmvs[MAX_CMVS_COUNT];
     unsigned int          type;
     char                  filename[PATH_MAX+1];
     unsigned int          nb_cmvs = 0;
@@ -872,7 +877,11 @@ static int send_cmvs ( const char *file )
     {
         strncpy (&filename[0], file, PATH_MAX);
     }
-    
+
+    /*
+     * Set max. number of CMVS in the furnished array
+     */
+    nb_cmvs = MAX_CMVS_COUNT;
     
     retcode = read_cmv_from_file ( filename, drv_cmvs, &nb_cmvs );
     if ( retcode != EXIT_SUCCESS ) 
@@ -909,7 +918,7 @@ static int send_cmvs ( const char *file )
     return (retcode);
     
 }
-#endif
+#endif /* USE_CMVS */
 
 /**
  * send_dsp - Send DSP data to driver
@@ -957,7 +966,7 @@ static int send_dsp ( const char *path )
      */
     if ( stat ( path, &buf) ) 
     {
-        fprintf (stderr,"Cannot stat %s (%d)\n",path,errno);
+        fprintf (stderr,"Cannot stat %s (%d)\n", path, errno);
         retcode = EXIT_FAILURE;
         goto byebye;
     }
@@ -1024,7 +1033,7 @@ static int send_dsp ( const char *path )
     pdsp = malloc (fsize);
     if ( pdsp == NULL ) 
     {
-        fprintf (stderr,"Can't allocate %d bytes !\n",fsize);
+        fprintf (stderr,"Can't allocate %lu bytes !\n", (unsigned long)fsize);
         retcode = EXIT_FAILURE;
         goto byebye;
     }
@@ -1274,14 +1283,16 @@ static void usage (void)
     printf ("  -v|--version         : display version number\n");
     printf ("  -o|--options [file]  : set options file \n");
     printf ("                         (file defaults to %s)\n",CONF_DIR "/" OPTS_FILE);
-/*     printf ("  -c|--cmvs [file]     : set CMVs file (autodetected)\n"); */
+#if USE_CMVS    
+    printf ("  -c|--cmvs [file]     : set CMVs file (autodetected)\n");
+#endif    
     printf ("  -d|--dsp [path]      : send Options, CMVS, and DSP file\n");
     printf ("                         path is either a path to the DSP file or to a directory\n"
             "                         containing DSP files for ISDN and POTS. In this case eaglectrl\n"
             "                         will choose which file to send to modem depending on the modem\n"
             "                         type. Defaults to %s\n",BIN_DIR);
     printf ("  -i|--if              : print modem interface name\n");
-    printf ("  -s|--sync  [sec]     : wait sec seconds for modem to be operationnal.\n"); 
+    printf ("  -s|--sync  [sec]     : wait sec seconds for modem to be operational.\n"); 
     printf ("                         If sec is 0 wait until synchro happens (infinite).\n");
     printf ("                         Default is 60\n");
     printf ("  -p|--print           : display detected devices\n");
@@ -1293,10 +1304,10 @@ static void usage (void)
             "                                DSP file and synchro timeout values to use.\n");
     printf ("  -g|--get-debug       :  Get debug mask\n");
     printf ("  -x|--set-debug dbg   : Set driver debug-mask to the given value,\n");
-    printf ("                         which can either be an haxadecimal number (0x0, 0xFF)\n");
-    printf ("                         or a lits of debug flags separated by a comma. A list of\n");
+    printf ("                         which can either be an hexadecimal number (0x0, 0xFF)\n");
+    printf ("                         or a list of debug flags separated by a comma. A list of\n");
     printf ("                         available flags can be given by the --list-debug option.\n");
-    
+    printf ("  -l|--list-debug      : Display a list of available flags for the debug-mask.\n");
     
     printf ("\n");
 }
@@ -1487,7 +1498,7 @@ static int open_dev (int state, unsigned int *type, int *other )
         else
         {
             fprintf (stderr,"**ERROR** Unable to open %s: errno=%d\n",
-                     getenv ("DEVICE"),errno);
+                     getenv ("DEVICE"), errno);
             return -1;
         }
         
@@ -1621,7 +1632,6 @@ static int parse_file ( FILE *in , eu_options_t *opts)
     unsigned int   section_detected = FALSE;
     size_t         length;
     int            i;
-    unsigned long  value;
     int            retcode    = TRUE;
     
     
@@ -1737,17 +1747,14 @@ static int parse_file ( FILE *in , eu_options_t *opts)
 
             REMOVE_CHAR (ptr,'\n');
             
-            value = 0;
-            while ( (*ptr != '\0') && ( isalnum ( (int)(*ptr)) ) )
+            (*opts)[i].value = (uint32_t) strtoul (ptr,NULL,16);
+            if (errno == ERANGE) 
             {
-                value = value << 4;
-                value = value + hex_to_byte (*ptr);
-                ptr++;
+                fprintf (stderr,"Value of option overflows on line %d\n", line_nb);
+		retcode = FALSE;
+		goto byebye;
             }
             
-            (*opts)[i].value = (int) value;
-
-            
         }
         else
         {
@@ -1933,7 +1940,7 @@ static int wizard (
             /* FALLTHROUGH */
             
         case POST_FIRMWARE:
-#if 0
+#if USE_CMVS
             /*
              * We need to send CMVs, options and then DSP code
              */
@@ -1946,7 +1953,7 @@ static int wizard (
                          dd->dev_name);
                 goto byebye;
             }
-#endif
+#endif /* USE_CMVS */
             fprintf (stdout,"Sending options to device %s\n",dd->dev_name);
             retcode = send_options ( opts );
             
@@ -2006,10 +2013,20 @@ static int wizard (
 
 }
 
-#if 0
+#if USE_CMVS
+/**
+ * Read the CMVs file.
+ *
+ * filename: path to the CMVs file
+ * drv_cmvs: pointer to CMV array.
+ * nb_cmvs: number of read CMVs. When the function is called it should hold the
+ *          max. number of CMVs the array can hold.
+ *
+ * return: EXIT_FAILURE / EXIT_SUCCESS
+ */
 static int read_cmv_from_file (
                                const char *filename,
-                               cmv_msg_t drv_cmvs[100],
+                               cmv_msg_t *drv_cmvs,
                                unsigned int *nb_cmvs
                               ) 
 {
@@ -2018,14 +2035,14 @@ static int read_cmv_from_file (
     char         *ptr;
     int           i;
     FILE         *fp      = NULL;
+    unsigned int max_cmvs;
     int           retcode = EXIT_SUCCESS;
-    unsigned int  data    = 0;
-
     
     pcmvs = drv_cmvs;
+    max_cmvs = *nb_cmvs;
     *nb_cmvs = 0;
     
-    for (i=0,pcmvs = drv_cmvs; i<100; i++, pcmvs++ ) 
+    for (i=0,pcmvs = drv_cmvs; i<max_cmvs; i++, pcmvs++ ) 
     {
         pcmvs->preamble = PREAMBLE;
         pcmvs->function = WRITE_TO_MODEM;
@@ -2058,6 +2075,15 @@ static int read_cmv_from_file (
             continue;
         }
 
+        if ( (*nb_cmvs) >= (max_cmvs-1) ) 
+        {
+            fprintf (stderr,"ERR: maximum number of CMVs (%u) reached.\n",
+                     max_cmvs-1);
+            retcode = EXIT_FAILURE;
+            goto byebye;
+        }
+
+        
         /* Skip spaces at beginning */
         ptr = &line[0];
         
@@ -2097,13 +2123,19 @@ static int read_cmv_from_file (
         
         
         /* Next 4 chars are either cntl or optn */
-        if ( ( strncasecmp (ptr,"OPTN",4) != 0 ) &&
-             ( strncasecmp (ptr,"CNTL",4) != 0 ) ) 
-        {
-            fprintf (stderr,"[ERR] CMV file line \"%s\" not treated (OPTN/CNTL)\n",line);
-            retcode = EXIT_FAILURE;
-            goto byebye;
-        }
+/*         if ( ( strncasecmp (ptr,"OPTN",4) != 0 ) && */
+/*              ( strncasecmp (ptr,"CNTL",4) != 0 ) )  */
+/*         { */
+/*             fprintf (stderr,"[ERR] CMV file line \"%s\" not treated (OPTN/CNTL)\n",line); */
+/*             retcode = EXIT_FAILURE; */
+/*             goto byebye; */
+/*         } */
+
+/*
+ * FIXME: Add a check on the type of message. Currently in last version
+ * furnished by ADI there are: optn, mask, diag, flag, cntl
+ * 
+ */
         
         pcmvs->sym_addr_hi_hi = toupper(ptr[0]);
         pcmvs->sym_addr_hi_lo = toupper(ptr[1]);
@@ -2136,16 +2168,17 @@ static int read_cmv_from_file (
         }
 
         /* And Data */
-        data = 0;
-        while (*ptr != '\0')
+        
+        pcmvs->data = (unsigned int) strtoul (ptr,NULL,16);
+        if (errno == ERANGE) 
         {
-            data = data << 4;
-            data = data + hex_to_byte (*ptr);
-            ptr++;
+            fprintf (stderr,"Value of option overflows (%s)\n", line);
+            retcode = EXIT_FAILURE;
+            goto byebye;
         }
-        pcmvs->data = data;
+
         pcmvs ++;
-        (*nb_cmvs) ++;
+        (*nb_cmvs) ++;        
     }    
 
     /*
@@ -2162,7 +2195,7 @@ static int read_cmv_from_file (
     
     return(retcode);
 }
-#endif
+#endif /* USE_CMVS */
 
 static void list_debug_flags (void ) 
 {
@@ -2360,43 +2393,3 @@ static int parse_dbg_flags ( char *flagstr, unsigned int *flags )
     return (result);
     
 }
-
-
-
-static uint8_t hex_to_byte(char c)
-{
-    int i;
-    switch (c)
-    {
-        case '0':
-        case '1':
-        case '2':
-        case '3':
-        case '4':
-        case '5':
-        case '6':
-        case '7':
-        case '8':
-        case '9':
-            i = (c - '0');
-            break;
-        case 'A':
-        case 'B':
-        case 'C':
-        case 'D':
-        case 'E':
-        case 'F':
-        case 'a':
-        case 'b':
-        case 'c':
-        case 'd':
-        case 'e':
-        case 'f':
-            i = (c & 0x0F) + 9;
-            break;
-        default:
-            assert(0);
-            break;
-    }
-    return i;
-}
