@@ -1,5 +1,3 @@
-
-
 #!/bin/bash
 #EagleConnect.tcl version 0.9  Copyright (C) 2004 Emmanuel Yves
 #Ce programme est libre, vous pouvez le redistribuer et /ou le modifier selon les termes
@@ -15,8 +13,14 @@
 
 
 set SBIN_DIR @SBIN_DIR@
+set EU_DIR @EU_DIR@
 set EU_EAGLECONNECT_DIR @EU_EAGLECONNECT_DIR@
 
+#set SBIN_DIR /usr/sbin
+#set EU_DIR /etc/eagle-usb
+#set EU_EAGLECONNECT_DIR /etc/eagle-usb/eagleconnect
+
+
 
 # La ligne suivante est executee par sh, pas par Tcl \
 exec wish "$0" ${1+"$@"}
@@ -30,7 +34,7 @@ package require msgcat;
 
 msgcat::mclocale $env(LANG);
 #::msgcat::mclocale "en_EN"
-msgcat::mcload /etc/eagle-usb/eagleconnect
+msgcat::mcload /etc/eagle-usb/eagleconnect/lang
 
 
 #ci-dessus, j'appelle le paquetage msgcat qui va me permettre d'afficher les messages
@@ -69,10 +73,10 @@ set login [exec whoami]
 
 
 cd $EU_EAGLECONNECT_DIR
-	set verifpresencepref [file exists $EU_EAGLECONNECT_DIR/eagleconnect.conf]
+	set verifpresencepref [file exists $EU_DIR/eagleconnect.conf]
 	if {$verifpresencepref > 0} {
 
-set contenupreferences [open $EU_EAGLECONNECT_DIR/eagleconnect.conf r];
+set contenupreferences [open $EU_DIR/eagleconnect.conf r];
 # j'ouvre le fichier eagleconnect.conf en lecture et j'affecte son contenu  la variable $contenupreferences
 
     if { ![eof $contenupreferences] } {
@@ -228,7 +232,7 @@ wm geometry .window 800x500+200+200; frame .window.fenetre; pack .window.fenetre
 
 
 text .window.fenetre.texteaide -height 500 -width 800  \
--background white -font {Fixed 16} -wrap word -yscrollcommand ".window.fenetre.scroll set";
+-background white -font {Fixed 12} -wrap word -yscrollcommand ".window.fenetre.scroll set";
 
 # je cre l'ascenseur  
 scrollbar .window.fenetre.scroll -command ".window.fenetre.texteaide yview";
@@ -240,9 +244,9 @@ pack .window.fenetre.scroll -side right -fill y;
 pack .window.fenetre.texteaide -expand yes -fill both
 
 
-# J'ouvre le fichier "EagleConnectDocumentation.txt" en lecture et j'affecte son contenu  la 
+# J'ouvre la documentation (format texte) en lecture et j'affecte son contenu  la 
 # variable "eagleconnectdocumentation"
-set eagleconnectdocumentation [ open  /etc/eagle-usb/eagleconnect/doc/EagleConnectDocumentation.txt r ]
+set eagleconnectdocumentation [ open  /etc/eagle-usb/eagleconnect/lang/doc_fr.txt r ]
 
 
 while { ![eof $eagleconnectdocumentation] } {
@@ -326,7 +330,7 @@ if {$frequence == "interval"} {
       
       close $recuprechdiag;
       after 300000 lancediaginterval;
-      puts "toutes les 5 minutes";
+     # puts "toutes les 5 minutes";
 
 
 
@@ -346,7 +350,9 @@ if {$frequence == "interval"} {
         set trouve [string first "KO" $texte]
         if {$trouve == -1} { 
            .maframe.appel delete 0 50;
-           .maframe.appel insert 0 [msgcat::mc "ADSL connection is active"];} else {puts "erreur2"; tk_messageBox -message [msgcat::mc "An error has occured. ADSL connection couldn't be established"]; 
+           .maframe.appel insert 0 [msgcat::mc "ADSL connection is active"];} else {
+	    # puts "erreur2"; 
+	   tk_messageBox -message [msgcat::mc "An error has occured. ADSL connection couldn't be established"]; 
            .maframe.appel delete 0 50;
            .maframe.appel insert 0 [msgcat::mc "ADSL connection isn't active"];
 	   changebouton;
@@ -395,7 +401,7 @@ if {$frequence == "interval"} {
 # Je construis le widget "appel" dans lequel apparatra le statut de la connexion (actif / inactif)
 
 
-  entry .maframe.appel -background white -justify center\
+  entry .maframe.appel -background white -justify center -font [list BBouton]\
  -textvariable statutconnexion \
  -width 35; \
   pack configure .maframe.appel -pady 15
@@ -945,7 +951,7 @@ proc lancediaginterval {} {
 
 
 cd $EU_EAGLECONNECT_DIR
-set verifpresencepref [file exists $EU_EAGLECONNECT_DIR/eagleconnect.conf]
+set verifpresencepref [file exists $EU_DIR/eagleconnect.conf]
 if {$verifpresencepref > 0} {
 	detectviaeaglediag unefois; after 60000 lancediaginterval; set variableinutile 1} else {
 	set variablenonuse 1;
